@@ -40,7 +40,6 @@
 #include <eel/eel-vfs-extensions.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libgnomeui/gnome-uidefs.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <stdio.h>
 #include <string.h>
@@ -411,6 +410,24 @@ check_same_fs (NautilusFile *file1,
 	return result;
 }
 
+static gboolean
+source_is_deletable (GFile *file)
+{
+	NautilusFile *naut_file;
+	gboolean ret;
+
+	/* if there's no a cached NautilusFile, it returns NULL */
+	naut_file = nautilus_file_get_existing (file);
+	if (naut_file == NULL) {
+		return FALSE;
+	}
+	
+	ret = nautilus_file_can_delete (naut_file);
+	nautilus_file_unref (naut_file);
+
+	return ret;
+}
+
 void
 nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 					     const char *target_uri_string, const GList *items,
@@ -418,8 +435,9 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 {
 	gboolean same_fs;
 	gboolean target_is_source_parent;
+	gboolean source_deletable;
 	const char *dropped_uri;
-	GFile *target, *dropped;
+	GFile *target, *dropped, *dropped_directory;
 	GdkDragAction actions;
 	NautilusFile *dropped_file, *target_file;
 
@@ -469,6 +487,10 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 		return;
 	} else if (eel_uri_is_desktop (target_uri_string)) {
 		target = nautilus_get_desktop_location ();
+
+		nautilus_file_unref (target_file);
+		target_file = nautilus_file_get (target);
+
 		if (eel_uri_is_desktop (dropped_uri)) {
 			/* Only move to Desktop icons */
 			if (actions & GDK_ACTION_MOVE) {
@@ -497,9 +519,19 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 	
 	/* Compare the first dropped uri with the target uri for same fs match. */
 	dropped = g_file_new_for_uri (dropped_uri);
-	target_is_source_parent = g_file_has_prefix (dropped, target);
-	
-	if (same_fs || target_is_source_parent ||
+	dropped_directory = g_file_get_parent (dropped);
+	target_is_source_parent = FALSE;
+	if (dropped_directory != NULL) {
+		/* If the dropped file is already in the same directory but
+		   is in another filesystem we still want to move, not copy
+		   as this is then just a move of a mountpoint to another
+		   position in the dir */
+		target_is_source_parent = g_file_equal (dropped_directory, target);
+		g_object_unref (dropped_directory);
+	}
+	source_deletable = source_is_deletable (dropped);
+
+	if ((same_fs && source_deletable) || target_is_source_parent ||
 	    g_file_has_uri_scheme (dropped, "trash")) {
 		if (actions & GDK_ACTION_MOVE) {
 			*action = GDK_ACTION_MOVE;
@@ -784,9 +816,9 @@ nautilus_drag_drop_action_ask (GtkWidget *widget,
 	gtk_grab_remove (menu);
 	
 	g_main_loop_unref (damd.loop);
-	
-	gtk_object_sink (GTK_OBJECT (menu));
-	
+
+	g_object_ref_sink (menu);	
+
 	return damd.chosen;
 }
 
@@ -837,9 +869,9 @@ nautilus_drag_drop_background_ask (GtkWidget *widget,
 	gtk_grab_remove (menu);
 	
 	g_main_loop_unref (damd.loop);
-	
-	gtk_object_sink (GTK_OBJECT (menu));
-	
+
+	g_object_ref_sink (menu);
+
 	return damd.chosen;	
 }
 
