@@ -41,18 +41,17 @@
 typedef struct NautilusFile NautilusFile;
 #endif
 
-#define NAUTILUS_TYPE_FILE \
-	(nautilus_file_get_type ())
+#define NAUTILUS_TYPE_FILE nautilus_file_get_type()
 #define NAUTILUS_FILE(obj) \
-	(GTK_CHECK_CAST ((obj), NAUTILUS_TYPE_FILE, NautilusFile))
+  (G_TYPE_CHECK_INSTANCE_CAST ((obj), NAUTILUS_TYPE_FILE, NautilusFile))
 #define NAUTILUS_FILE_CLASS(klass) \
-	(GTK_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_FILE, NautilusFileClass))
+  (G_TYPE_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_FILE, NautilusFileClass))
 #define NAUTILUS_IS_FILE(obj) \
-	(GTK_CHECK_TYPE ((obj), NAUTILUS_TYPE_FILE))
+  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NAUTILUS_TYPE_FILE))
 #define NAUTILUS_IS_FILE_CLASS(klass) \
-	(GTK_CHECK_CLASS_TYPE ((klass), NAUTILUS_TYPE_FILE))
+  (G_TYPE_CHECK_CLASS_TYPE ((klass), NAUTILUS_TYPE_FILE))
 #define NAUTILUS_FILE_GET_CLASS(obj) \
-	(G_TYPE_INSTANCE_GET_CLASS ((obj), NAUTILUS_TYPE_FILE, NautilusFileClass))
+  (G_TYPE_INSTANCE_GET_CLASS ((obj), NAUTILUS_TYPE_FILE, NautilusFileClass))
 
 typedef enum {
 	NAUTILUS_FILE_SORT_NONE,
@@ -121,8 +120,8 @@ NautilusFile *          nautilus_file_get_by_uri                        (const c
 NautilusFile *          nautilus_file_get_existing                      (GFile                          *location);
 NautilusFile *          nautilus_file_get_existing_by_uri               (const char                     *uri);
 
-/* Covers for gtk_object_ref and gtk_object_unref that provide two conveniences:
- * 1) You don't have to cast to GtkObject *, so using these is type safe.
+/* Covers for g_object_ref and g_object_unref that provide two conveniences:
+ * 1) Using these is type safe.
  * 2) You are allowed to call these with NULL,
  */
 NautilusFile *          nautilus_file_ref                               (NautilusFile                   *file);
