@@ -44,7 +44,7 @@
 
 #define AUTO_SCROLL_MARGIN 20
 
-#define HOVER_EXPAND_TIMEOUT 1000
+#define HOVER_EXPAND_TIMEOUT 1
 
 struct _NautilusTreeViewDragDestDetails {
 	GtkTreeView *tree_view;
@@ -491,7 +491,7 @@ drag_motion_callback (GtkWidget *widget,
 		if (dest->details->expand_id == 0 && drop_path != NULL) {
 			gtk_tree_model_get_iter (model, &drop_iter, drop_path);
 			if (gtk_tree_model_iter_has_child (model, &drop_iter)) {
-				dest->details->expand_id = g_timeout_add (HOVER_EXPAND_TIMEOUT,
+				dest->details->expand_id = g_timeout_add_seconds (HOVER_EXPAND_TIMEOUT,
 									  expand_timeout,
 									  dest->details->tree_view);
 			}
@@ -598,7 +598,8 @@ receive_uris (NautilusTreeViewDragDest *dest,
 	}
 
 	if (context->action > 0) {
-		if (!nautilus_drag_uris_local (drop_target, source_uris)) {
+		if (!nautilus_drag_uris_local (drop_target, source_uris)
+			|| context->action != GDK_ACTION_MOVE) {
 			g_signal_emit (dest, signals[MOVE_COPY_ITEMS], 0,
 				       source_uris, 
 				       drop_target,
