@@ -29,16 +29,17 @@
 
 #include <gtk/gtk.h>
 
-#define NAUTILUS_TYPE_EMBLEM_SIDEBAR \
-	(nautilus_emblem_sidebar_get_type ())
+#define NAUTILUS_TYPE_EMBLEM_SIDEBAR nautilus_emblem_sidebar_get_type()
 #define NAUTILUS_EMBLEM_SIDEBAR(obj) \
-	(GTK_CHECK_CAST ((obj), NAUTILUS_TYPE_EMBLEM_SIDEBAR, NautilusEmblemSidebar))
+  (G_TYPE_CHECK_INSTANCE_CAST ((obj), NAUTILUS_TYPE_EMBLEM_SIDEBAR, NautilusEmblemSidebar))
 #define NAUTILUS_EMBLEM_SIDEBAR_CLASS(klass) \
-	(GTK_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_EMBLEM_SIDEBAR, NautilusEmblemSidebarClass))
+  (G_TYPE_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_EMBLEM_SIDEBAR, NautilusEmblemSidebarClass))
 #define NAUTILUS_IS_EMBLEM_SIDEBAR(obj) \
-	(GTK_CHECK_TYPE ((obj), NAUTILUS_TYPE_EMBLEM_SIDEBAR))
+  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NAUTILUS_TYPE_EMBLEM_SIDEBAR))
 #define NAUTILUS_IS_EMBLEM_SIDEBAR_CLASS(klass) \
-	(GTK_CHECK_CLASS_TYPE ((klass), NAUTILUS_TYPE_EMBLEM_SIDEBAR))
+  (G_TYPE_CHECK_CLASS_TYPE ((klass), NAUTILUS_TYPE_EMBLEM_SIDEBAR))
+#define NAUTILUS_EMBLEM_SIDEBAR_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_CLASS ((obj), NAUTILUS_TYPE_EMBLEM_SIDEBAR, NautilusEmblemSidebarClass))
 
 #define NAUTILUS_EMBLEM_SIDEBAR_ID "NautilusEmblemSidebar"
 
