@@ -27,10 +27,10 @@
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-stock-dialogs.h>
 #include <gtk/gtk.h>
-#include <libgnomeui/gnome-help.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include "nautilus-location-entry.h"
 #include "nautilus-desktop-window.h"
+#include <glib/gi18n.h>
 
 struct _NautilusLocationDialogDetails {
 	GtkWidget *entry;
@@ -101,10 +101,9 @@ response_callback (NautilusLocationDialog *dialog,
 		break;
 	case GTK_RESPONSE_HELP :
 		error = NULL;
-		gnome_help_display_desktop_on_screen (NULL, "user-guide", "user-guide.xml",
-						      "nautilus-open-location",
-						      gtk_window_get_screen (GTK_WINDOW (dialog)),
-						      &error);
+		gtk_show_uri (gtk_window_get_screen (GTK_WINDOW (dialog)),
+			      "ghelp:user-guide#nautilus-open-location",
+			      gtk_get_current_event_time (), &error);
 		if (error) {
 			eel_show_error_dialog (_("There was an error displaying help."), error->message,
 					       GTK_WINDOW (dialog));
@@ -123,7 +122,10 @@ entry_activate_callback (GtkEntry *entry,
 	NautilusLocationDialog *dialog;
 	
 	dialog = NAUTILUS_LOCATION_DIALOG (user_data);
-	gtk_dialog_response (GTK_DIALOG (dialog), RESPONSE_OPEN);
+
+	if (gtk_entry_get_text_length (GTK_ENTRY (dialog->details->entry)) != 0) {
+		gtk_dialog_response (GTK_DIALOG (dialog), RESPONSE_OPEN);
+	}
 }
 
 static void
@@ -139,6 +141,20 @@ nautilus_location_dialog_class_init (NautilusLocationDialogClass *class)
 	object_class->destroy = nautilus_location_dialog_destroy;
 }
 
+static void
+entry_text_changed (GObject *object, GParamSpec *spec, gpointer user_data)
+{
+	NautilusLocationDialog *dialog;
+
+	dialog = NAUTILUS_LOCATION_DIALOG (user_data);
+
+	if (gtk_entry_get_text_length (GTK_ENTRY (dialog->details->entry)) != 0) {
+		gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), RESPONSE_OPEN, TRUE);
+	} else {
+		gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), RESPONSE_OPEN, FALSE);
+	}
+}
+
 static void
 nautilus_location_dialog_init (NautilusLocationDialog *dialog)
 {
@@ -191,6 +207,9 @@ nautilus_location_dialog_init (NautilusLocationDialog *dialog)
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog),
 					 RESPONSE_OPEN);
 
+	g_signal_connect (dialog->details->entry, "notify::text", 
+                          G_CALLBACK (entry_text_changed), dialog);
+
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (response_callback),
 			  dialog);
