@@ -519,7 +519,7 @@ action_about_nautilus_callback (GtkAction *action,
 			       "comments", _("Nautilus lets you organize "
 					     "files and folders, both on "
 					     "your computer and online."),
-			       "copyright", _("Copyright \xC2\xA9 1999-2008 "
+			       "copyright", _("Copyright \xC2\xA9 1999-2009 "
 					      "The Nautilus authors"),
 			       "license", license_trans,
 			       "wrap-license", TRUE,
@@ -531,7 +531,7 @@ action_about_nautilus_callback (GtkAction *action,
 				 */
 			      "translator-credits", _("translator-credits"),
 			      "logo-icon-name", "nautilus",
-			      "website", "http://www.gnome.org/projects/nautilus",
+			      "website", "http://live.gnome.org/Nautilus",
 			      "website-label", _("Nautilus Web Site"),
 			      NULL);
 
@@ -979,7 +979,7 @@ add_extension_menu_items (NautilusWindow *window,
 		g_object_get (item, "menu", &menu, NULL);
 		
 		action = nautilus_action_from_menu_item (item);
-		gtk_action_group_add_action (action_group, action);
+		gtk_action_group_add_action_with_accel (action_group, action, NULL);
 		
 		path = g_build_path ("/", POPUP_PATH_EXTENSION_ACTIONS, subdirectory, NULL);
 		gtk_ui_manager_add_ui (ui_manager,
